from cpl_core.configuration import ConfigurationModelABC
from cpl_core.utils.json_processor import JSONProcessor
from cpl_query.extension import List

from bot_core.configuration.server_settings import ServerSettings


class BotSettings(ConfigurationModelABC):
    def __init__(
        self,
        technicians: list = None,
        wait_for_restart: int = 2,
        wait_for_shutdown: int = 2,
        cache_max_messages: int = 1000,
        **kwargs: dict,
    ):
        ConfigurationModelABC.__init__(self)

        self._technicians: List[int] = List(int) if technicians is None else technicians
        self._wait_for_restart = wait_for_restart
        self._wait_for_shutdown = wait_for_shutdown
        self._cache_max_messages = cache_max_messages

        self._servers: List[ServerSettings] = List(ServerSettings)

        for s in kwargs:
            kwargs[s]["Id"] = s
            self._servers.append(JSONProcessor.process(ServerSettings, kwargs[s]))

    @property
    def servers(self) -> List[ServerSettings]:
        return self._servers

    @property
    def technicians(self) -> List[int]:
        return self._technicians

    @property
    def wait_for_restart(self) -> int:
        return self._wait_for_restart

    @property
    def wait_for_shutdown(self) -> int:
        return self._wait_for_shutdown

    @property
    def cache_max_messages(self) -> int:
        return self._cache_max_messages

    def _servers_from_dict(self, settings: dict):
        servers = List(ServerSettings)
        for s in settings:
            settings[s]["id"] = int(s)
            st = JSONProcessor.process(ServerSettings, settings[s])
            servers.append(st)
        self._servers = servers
